@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4; coding: utf-8 -*- 
  *
- * Copyright © 2007 Björn Lindqvist <bjourne@gmail.com>
+ * Copyright © 2007-2008 Björn Lindqvist <bjourne@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -80,11 +80,24 @@ G_DEFINE_TYPE(GtkAnimView, gtk_anim_view, GTK_TYPE_IMAGE_VIEW);
 /*************************************************************/
 /***** Static stuff ******************************************/
 /*************************************************************/
+
 static gboolean
 gtk_anim_view_updator (gpointer data)
 {
     GtkAnimView *aview = (GtkAnimView *) data;
-    g_time_val_add (&aview->time, (glong) aview->delay * 1000);
+
+    // Workaround for #437791.
+    glong delay_us = aview->delay * 1000;
+    if (aview->delay == 20)
+    {
+        // If the delay time is 20 ms, the GIF is a "fast player." and
+        // we increase it to a more reasonable 100 ms so that the
+        // frame is only updated 1/5 of the times
+        // gtk_anim_view_updator() is run.
+        delay_us = 200;
+    }
+    g_time_val_add (&aview->time, delay_us);
+
     gboolean next = gdk_pixbuf_animation_iter_advance (aview->iter,
                                                        &aview->time);
     gtk_anim_view_set_is_playing (aview, FALSE);
@@ -102,7 +115,6 @@ gtk_anim_view_updator (gpointer data)
     return FALSE;
 }
 
-
 /*************************************************************/
 /***** Private signal handlers *******************************/
 /*************************************************************/
@@ -240,7 +252,12 @@ gtk_anim_view_get_anim (GtkAnimView *aview)
  *
  * Sets the pixbuf animation to play, or %NULL to not play any
  * animation.
-
+ *
+ * If the animation is a static image or only has one frame, then the
+ * static image will be displayed instead. If more frames are loaded
+ * into the animation, then #GtkAnimView will automatically animate to
+ * those frames.
+ *
  * The effect of this method is analoguous to
  * gtk_image_view_set_pixbuf(). Fit mode is reset to
  * %GTK_FIT_SIZE_IF_LARGER so that the whole area of the animation
@@ -270,6 +287,9 @@ gtk_anim_view_set_anim (GtkAnimView        *aview,
     aview->iter = gdk_pixbuf_animation_get_iter (aview->anim, &aview->time);
 
     GdkPixbuf *pixbuf = gdk_pixbuf_animation_iter_get_pixbuf (aview->iter);
+    if (gdk_pixbuf_animation_is_static_image (anim))
+        pixbuf = gdk_pixbuf_animation_get_static_image (anim);
+
     gtk_image_view_set_pixbuf (GTK_IMAGE_VIEW (aview), pixbuf, TRUE);
 
     gtk_anim_view_set_is_playing (aview, FALSE);
@@ -329,6 +349,26 @@ void
 gtk_anim_view_step (GtkAnimView *aview)
 {
     if (aview->anim)
-        gtk_anim_view_updator (aview);
+    {
+        // Part of workaround for #437791. gtk_anim_view_updator()
+        // might not always immidiately step to the next frame, so we
+        // loop until the frame is changed.
+        //
+        // If we are on the last frame, it will not wrap around so the
+        // frame will never change. So we risk an infinite loop.
+        // Unfortunately but expectedly, GdkPixbufAnimationIter
+        // doesn't provide a way to check if we
+        // are on the last frame because the API is totally brain
+        // damaged. The work-around is to give gtk_anim_view_updator
+        // exactly 10 chances to advance the frame before bailing out.
+        int n = 0;
+        GdkPixbuf *old = gdk_pixbuf_animation_iter_get_pixbuf (aview->iter);
+        while ((gdk_pixbuf_animation_iter_get_pixbuf (aview->iter) == old) &&
+               (n < 10))            
+        {
+            gtk_anim_view_updator (aview);
+            n++;
+        }
+    }
     gtk_anim_view_set_is_playing (aview, FALSE);
 }
