@@ -9,8 +9,13 @@ main (int argc, char *argv[])
 {
     gtk_init (&argc, &argv);
 
-    char *fname = "/home/bjourne/images/pollen.gif";
-    GdkPixbufAnimation *anim = gdk_pixbuf_animation_new_from_file (fname,
+    if (argc != 2)
+    {
+        printf ("usage: ex-anim <image>\n");
+        return 1;
+    }
+
+    GdkPixbufAnimation *anim = gdk_pixbuf_animation_new_from_file (argv[1],
                                                                    NULL);
 
     GtkWidget *window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
