@@ -12,6 +12,11 @@
 #include <src/gtkimagetoolpainter.h>
 #include <src/gtkimagetoolselector.h>
 
+// Defines for backwards compatibility with GTK+ 2.6
+#if !GTK_CHECK_VERSION(2,8,0)
+#define GTK_STOCK_FULLSCREEN ""
+#endif
+
 //////////////////////////////////////////////////////////////////////
 ///// Global data ////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////
@@ -201,7 +206,7 @@ transform_cb ()
             for (int n  = 0; n < 3; n++)
                 p[n] ^= 0xff;
         }
-    gtk_image_view_set_pixbuf (GTK_IMAGE_VIEW (view), pixbuf, FALSE);
+    gtk_image_view_damage_pixels (GTK_IMAGE_VIEW (view), NULL);
 }
 
 static void
