@@ -7,34 +7,7 @@
 #include <src/gtkimageview.h>
 #include <src/gtkzooms.h>
 #include <assert.h>
-
-/* A fake realization function for GtkImageView. The normal can not be
-   used because gdk does not like it. */
-static void
-fake_realize (GtkWidget *widget)
-{
-	GdkWindowAttr attrs;
-    attrs.window_type = GDK_WINDOW_CHILD;
-    attrs.x = widget->allocation.x;
-    attrs.y = widget->allocation.y;
-    attrs.width = widget->allocation.width;
-    attrs.height = widget->allocation.height;
-    attrs.wclass = GDK_INPUT_OUTPUT;
-    attrs.visual = gtk_widget_get_visual (widget);
-    attrs.colormap = gtk_widget_get_colormap (widget);
-    attrs.event_mask = (gtk_widget_get_events (widget)
-                        | GDK_EXPOSURE_MASK
-                        | GDK_BUTTON_MOTION_MASK
-                        | GDK_BUTTON_PRESS_MASK
-                        | GDK_BUTTON_RELEASE_MASK
-                        | GDK_POINTER_MOTION_MASK);
-                        
-    int attr_mask = (GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP);
-    widget->window = gdk_window_new (NULL, &attrs, attr_mask);
-
-	widget->style = gtk_style_attach (widget->style, widget->window);
-    gtk_style_set_background (widget->style, widget->window, GTK_STATE_NORMAL);
-}
+#include "testlib/testlib.h"
 
 /**
  * test_that_image_is_fitted_after_size_changes:
@@ -81,7 +54,9 @@ test_that_image_is_fitted_after_size_changes ()
             gdouble height_ratio = (gdouble) alloc_height / img_height;
 
             gdouble expected_zoom = MIN (width_ratio, height_ratio);
-			expected_zoom = MIN (expected_zoom, 1.0);
+			expected_zoom = CLAMP (expected_zoom,
+                                   gtk_zooms_get_min_zoom (),
+                                   1.0);
 	    
             assert (gtk_image_view_get_zoom (view) == expected_zoom);
             
@@ -130,10 +105,18 @@ test_size_allocate_at_image_boundary ()
 	g_assert (hadj);
 	gtk_adjustment_set_value (GTK_ADJUSTMENT (hadj), 300.0);
 
-	/* The viewport should now match the rectangle (300, 0)-(200, 200) */
+	
+    GMainContext *main_ctx = g_main_context_default ();
+    while (g_main_context_pending (main_ctx))
+    {
+        g_main_context_iteration (main_ctx, TRUE);
+        g_usleep (1000 * 100);
+    }
+
+    /* The viewport should now match the rectangle (300, 0)-(200, 200) */
 	GdkRectangle viewport;
 	gtk_image_view_get_viewport (GTK_IMAGE_VIEW (view), &viewport);
-
+    
     assert (gdk_rectangle_eq (viewport, (GdkRectangle){300, 0, 200, 200}));
 
 	/* Now expand the widget by making its width 100 pixels
