@@ -4,40 +4,13 @@
  **/
 #include <src/gtkimagetoolselector.h>
 #include <assert.h>
+#include "testlib/testlib.h"
 
 static GtkImageView *view = NULL;
 // Use two global variables to avoid castings.
 static GtkIImageTool *tool = NULL;
 static GtkImageToolSelector *selector = NULL;
 
-/* A fake realization function for GtkImageView. The normal can not be
-   used because gdk does not like it. */
-static void
-fake_realize (GtkWidget *widget)
-{
-    GdkWindowAttr attrs;
-    attrs.window_type = GDK_WINDOW_CHILD;
-    attrs.x = widget->allocation.x;
-    attrs.y = widget->allocation.y;
-    attrs.width = widget->allocation.width;
-    attrs.height = widget->allocation.height;
-    attrs.wclass = GDK_INPUT_OUTPUT;
-    attrs.visual = gtk_widget_get_visual (widget);
-    attrs.colormap = gtk_widget_get_colormap (widget);
-    attrs.event_mask = (gtk_widget_get_events (widget)
-                        | GDK_EXPOSURE_MASK
-                        | GDK_BUTTON_MOTION_MASK
-                        | GDK_BUTTON_PRESS_MASK
-                        | GDK_BUTTON_RELEASE_MASK
-                        | GDK_POINTER_MOTION_MASK);
-                        
-    int attr_mask = (GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP);
-    widget->window = gdk_window_new (NULL, &attrs, attr_mask);
-
-    widget->style = gtk_style_attach (widget->style, widget->window);
-    gtk_style_set_background (widget->style, widget->window, GTK_STATE_NORMAL);
-}
-
 static void
 setup ()
 {
