@@ -6,37 +6,10 @@
 #include <src/gtkimageview.h>
 #include <src/gtkzooms.h>
 #include <assert.h>
+#include "testlib/testlib.h"
 
 static GtkImageView *view = NULL;
 
-/* A fake realization function for GtkImageView. The normal can not be
-   used because gdk does not like it. */
-static void
-fake_realize (GtkWidget *widget)
-{
-    GdkWindowAttr attrs;
-    attrs.window_type = GDK_WINDOW_CHILD;
-    attrs.x = widget->allocation.x;
-    attrs.y = widget->allocation.y;
-    attrs.width = widget->allocation.width;
-    attrs.height = widget->allocation.height;
-    attrs.wclass = GDK_INPUT_OUTPUT;
-    attrs.visual = gtk_widget_get_visual (widget);
-    attrs.colormap = gtk_widget_get_colormap (widget);
-    attrs.event_mask = (gtk_widget_get_events (widget)
-                        | GDK_EXPOSURE_MASK
-                        | GDK_BUTTON_MOTION_MASK
-                        | GDK_BUTTON_PRESS_MASK
-                        | GDK_BUTTON_RELEASE_MASK
-                        | GDK_POINTER_MOTION_MASK);
-                        
-    int attr_mask = (GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP);
-    widget->window = gdk_window_new (NULL, &attrs, attr_mask);
-
-    widget->style = gtk_style_attach (widget->style, widget->window);
-    gtk_style_set_background (widget->style, widget->window, GTK_STATE_NORMAL);
-}
-
 static void
 setup ()
 {
@@ -105,7 +78,7 @@ test_boundary_zoom_values ()
 {
     printf ("test_boundary_zoom_values\n");
     setup ();
-    gdouble small_zooms[] = {-99.0, -12324.0, 0.0, 0.001, 0.049, 0.009};
+    gdouble small_zooms[] = {-99.0, -12324.0, 0.0, 0.001, 0.019, 0.009};
     for (int n = 0; n < G_N_ELEMENTS(small_zooms); n++)
     {
         gtk_image_view_set_zoom (view, small_zooms[n]);
@@ -150,7 +123,9 @@ test_zooming_in_and_out ()
     }
 
     gtk_image_view_set_zoom (view, 1.0);
-    gdouble zoom_outs[] = {0.75, 0.5, 0.3, 0.2, 0.15, 0.10, 0.07, 0.05};
+    gdouble zoom_outs[] = {
+        0.75, 0.5, 0.3, 0.2, 0.15, 0.10, 0.07, 0.05, 0.02
+    };
     for (int n = 0; n < G_N_ELEMENTS(zoom_outs); n++)
     {
         gtk_image_view_zoom_out (view);
